@@ -50,7 +50,6 @@ impl BestTickFinder {
             best: Candidate {
                 ticks: Vec::new(),
                 unit_data: StepUnit::YR,
-                //dash_nums: &[],
                 chosen_tick: 0,
             },
         }
@@ -81,6 +80,15 @@ impl BestTickFinder {
 
     ///Returns true if the candidate was chosen
     fn consider_set(&mut self, candidate: Candidate) -> bool {
+        if candidate.ticks.len() < 2 {
+            return false;
+        }
+
+        if self.best.ticks.len() < 2 {
+            self.best = candidate;
+            return true;
+        }
+
         let new_closeness = (self.ideal_num_steps as i64 - candidate.ticks.len() as i64).abs();
         let old_closeness = (self.ideal_num_steps as i64 - self.best.ticks.len() as i64).abs();
 
