@@ -176,69 +176,3 @@ impl<T: std::fmt::Write> std::fmt::Write for WriteCounter<T> {
         self.writer.write_str(s)
     }
 }
-
-pub(crate) fn find_bounds<X: PlotNum, Y: PlotNum>(
-    it: impl IntoIterator<Item = (X, Y)>,
-    xmarkers: impl IntoIterator<Item = X>,
-    ymarkers: impl IntoIterator<Item = Y>,
-) -> ([X; 2], [Y; 2]) {
-    let mut ii = it.into_iter().filter(|(x, y)| !x.is_hole() && !y.is_hole());
-
-    if let Some((x, y)) = ii.next() {
-        let mut val = ([x, x], [y, y]);
-        let mut xmoved = false;
-        let mut ymoved = false;
-
-        let ii = ii
-            .chain(
-                xmarkers
-                    .into_iter()
-                    .filter(|a| !a.is_hole())
-                    .map(|xx| (xx, y)),
-            )
-            .chain(
-                ymarkers
-                    .into_iter()
-                    .filter(|a| !a.is_hole())
-                    .map(|yy| (x, yy)),
-            );
-
-        ii.fold(&mut val, |val, (x, y)| {
-            if x < val.0[0] {
-                val.0[0] = x;
-                if !xmoved {
-                    xmoved = true
-                };
-            } else if x > val.0[1] {
-                val.0[1] = x;
-                if !xmoved {
-                    xmoved = true
-                };
-            }
-            if y < val.1[0] {
-                val.1[0] = y;
-                if !ymoved {
-                    ymoved = true
-                };
-            } else if y > val.1[1] {
-                val.1[1] = y;
-                if !ymoved {
-                    ymoved = true
-                };
-            }
-            val
-        });
-
-        if !xmoved {
-            val.0 = X::unit_range(Some(x));
-        }
-
-        if !ymoved {
-            val.1 = Y::unit_range(Some(y));
-        }
-
-        val
-    } else {
-        (X::unit_range(None), Y::unit_range(None))
-    }
-}
